==> flow-client-2.7.15-sources.jar: com/vaadin/flow/server/InvalidI18NConfigurationException.java <==
/*
 * Copyright 2000-2020 Vaadin Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.vaadin.flow.server;

/**
 * Exception indicating that the application's I18N localization has been
 * configured incorrectly.
 *
 * @since 1.0
 */
public class InvalidI18NConfigurationException extends RuntimeException {

    /**
     * Constructs a new invalid I18N localization configuration runtime
     * exception with the specified detail message.
     *
     * @param message
     *            the detail message. The detail message is saved for later
     *            retrieval by the {@link #getMessage()} method.
     */
    public InvalidI18NConfigurationException(String message) {
        super(message);
    }

    /**
     * Constructs a new invalid I18N localization configuration runtime
     * exception with the specified detail message.
     *
     * @param message
     *            the detail message. The detail message is saved for later
     *            retrieval by the {@link #getMessage()} method.
     * @param cause
     *            the cause (which is saved for later retrieval by the
     *            {@link #getCause()} method). (A <tt>null</tt> value is
     *            permitted, and indicates that the cause is nonexistent or
     *            unknown.)
     */
    public InvalidI18NConfigurationException(String message, Throwable cause) {
        super(message, cause);
    }
}

==> flow-client-9.2.3-sources.jar: com/vaadin/flow/server/InvalidI18NConfigurationException.java <==
/**
 * Copyright (C) 2000-2023 Vaadin Ltd
 *
 * This program is available under Vaadin Commercial License and Service Terms.
 *
 * See <https://vaadin.com/commercial-license-and-service-terms> for the full
 * license.
 */
package com.vaadin.flow.server;

/**
 * Exception indicating that the application's I18N localization has been
 * configured incorrectly.
 *
 * @since 1.0
 */
public class InvalidI18NConfigurationException extends RuntimeException {

    /**
     * Constructs a new invalid I18N localization configuration runtime
     * exception with the specified detail message.
     *
     * @param message
     *            the detail message. The detail message is saved for later
     *            retrieval by the {@link #getMessage()} method.
     */
    public InvalidI18NConfigurationException(String message) {
        super(message);
    }

    /**
     * Constructs a new invalid I18N localization configuration runtime
     * exception with the specified detail message.
     *
     * @param message
     *            the detail message. The detail message is saved for later
     *            retrieval by the {@link #getMessage()} method.
     * @param cause
     *            the cause (which is saved for later retrieval by the
     *            {@link #getCause()} method). (A <code>null</code> value is
     *            permitted, and indicates that the cause is nonexistent or
     *            unknown.)
     */
    public InvalidI18NConfigurationException(String message, Throwable cause) {
        super(message, cause);
    }
}
